@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2012-2016 Montel Laurent <montel@kde.org>
+   Copyright (C) 2012-2017 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -37,7 +37,7 @@ class ImportWizardKernel : public QObject, public MailCommon::IKernel, public Ma
 {
     Q_OBJECT
 public:
-    explicit ImportWizardKernel(QObject *parent = Q_NULLPTR);
+    explicit ImportWizardKernel(QObject *parent = nullptr);
 
     KIdentityManagement::IdentityManager *identityManager() Q_DECL_OVERRIDE;
     MessageComposer::MessageSender *msgSender() Q_DECL_OVERRIDE;
@@ -59,11 +59,9 @@ public:
 
 private:
     KIdentityManagement::IdentityManager *mIdentityManager;
-    MessageComposer::MessageSender *mMessageSender;
     MailCommon::FolderCollectionMonitor *mFolderCollectionMonitor;
     Akonadi::EntityTreeModel *mEntityTreeModel;
     Akonadi::EntityMimeTypeFilterModel *mCollectionModel;
-
 };
 
 #endif
